CustomButton class

Inheritance

Constructors

CustomButton({Key? key, required String text, required VoidCallback? onPressed, Color? color, LinearGradient? gradient, Color textColor = Colors.white, double radius = 10.0, double elevation = 4.0, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 18, vertical: 14), IconData? icon, bool isLoading = false, bool showGlow = true, LinearGradient? borderGradient, double borderWidth = 2.0})
const

Properties

borderGradient LinearGradient?
final
borderWidth double
final
color Color?
final
elevation double
final
gradient LinearGradient?
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
final
isLoading bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed VoidCallback?
final
padding EdgeInsetsGeometry
final
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showGlow bool
final
text String
final
textColor Color
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CustomButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited